@@ -251,7 +251,7 @@ class REGFBlock(RegistryBlock):
         """
         Get the hive name of the open Windows Registry file as a string.
         """
-        return self.unpack_string(0x30, 64)
+        return self.unpack_string(0x30, 64).decode("utf-16le").rstrip("\x00")
 
     def last_hbin_offset(self):
         """
@@ -459,7 +459,7 @@ class DBIndirectBlock(Record):
     def large_data(self, length):
         """
         Get the data pointed to by the indirect block. It may be large.
-        Return a byte array.
+        Return a byte string.
         """
         b = bytearray()
         count = 0
@@ -470,7 +470,7 @@ class DBIndirectBlock(Record):
 
             count += 1
             length -= size
-        return b
+        return str(b)
 
 class DBRecord(Record):
     """
@@ -593,10 +593,6 @@ class VKRecord(Record):
         Is the name of this value in the ASCII charset?
         Note, this doesnt work, yet... TODO
         """
-        if self.unpack_word(0x10) & 1 == 1:
-            print "ascii name"
-        else:
-            print "not ascii name"
         return self.unpack_word(0x10) & 1 == 1
 
     def name(self):
@@ -1032,7 +1028,7 @@ class NKRecord(Record):
 
         offset = self.abs_offset_from_hbin_offset(classname_offset)
         d = HBINCell(self._buf, offset, self)
-        return struct.unpack_from("<%ds" % (classname_length), self._buf, d.data_offset())[0]
+        return struct.unpack_from("<%ds" % (classname_length), self._buf, d.data_offset())[0].decode("utf-16le").rstrip("\x00")
 
     def timestamp(self):
         """
@@ -1153,7 +1149,6 @@ class NKRecord(Record):
         elif id_ == "li":
             l = LIRecord(self._buf, d.data_offset(), self)
         else:
-            print id_ + " subkey list"
             raise ParseException("Subkey list with type %s encountered, but not yet supported." % (id_))
 
         return l
@@ -1203,7 +1198,7 @@ class HBINBlock(RegistryBlock):
         try:
             HBINBlock(self._buf, self._offset_next_hbin, self.parent())
             return True
-        except ParseException:
+        except (ParseException, struct.error):
             return False
 
     def next(self):
